@@ -129,7 +129,7 @@ void ClientUserInputHandler::switchBuffer(const NetworkId &networkId, const QStr
         QList<ClientBufferViewConfig *> bufferViewConfigList = clientBufferViewManager->clientBufferViewConfigs();
         foreach(ClientBufferViewConfig *bufferViewConfig, bufferViewConfigList) {
             if (bufferViewConfig->temporarilyRemovedBuffers().contains(newBufId)) {
-                bufferViewConfig->addBuffer(newBufId, bufferViewConfig->bufferList().length());
+                bufferViewConfig->requestAddBuffer(newBufId, bufferViewConfig->bufferList().length());
                 //if (bufferViewConfig->sortAlphabetically()) {
                 // TODO we need to trigger a sort here, but can't reach the model required
                 // to get a bufferviewfilter, as the bufferviewmanager only managers configs
