@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2013 by the Quassel Project                        *
+ *   Copyright (C) 2005-2014 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,18 +31,19 @@
 #include <QCoreApplication>
 #include <QDateTime>
 #include <QFileInfo>
+#include <QHostAddress>
 #include <QLibraryInfo>
 #include <QSettings>
 #include <QTranslator>
-#include <QHostAddress>
 
-#include "message.h"
-#include "identity.h"
-#include "network.h"
 #include "bufferinfo.h"
-#include "types.h"
-#include "syncableobject.h"
+#include "identity.h"
 #include "logger.h"
+#include "message.h"
+#include "network.h"
+#include "protocol.h"
+#include "syncableobject.h"
+#include "types.h"
 
 Quassel::BuildInfo Quassel::_buildInfo;
 AbstractCliParser *Quassel::_cliParser = 0;
@@ -196,6 +197,8 @@ void Quassel::registerMetaTypes()
     qRegisterMetaTypeStreamOperators<AccountId>("AccountId");
     qRegisterMetaTypeStreamOperators<MsgId>("MsgId");
 
+    qRegisterMetaType<Protocol::SessionState>("Protocol::SessionState");
+
     // Versions of Qt prior to 4.7 didn't define QVariant as a meta type
     if (!QMetaType::type("QVariant")) {
         qRegisterMetaType<QVariant>("QVariant");
