@@ -89,6 +89,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Terje \"tan\" Andersen</b></dt><dd>Norwegian translation, documentation</dd>"
                               "<dt><b>Jens \"amiconn\" Arnold</b></dt><dd>Postgres migration fixes</dd>"
                               "<dt><b>Adolfo Jayme Barrientos</b></dt><dd>Spanish translation</dd>"
+                              "<dt><b>Mattia Basaglia</b></dt><dd>Fixes</dd>"
                               "<dt><b>Pete \"elbeardmorez\" Beardmore</b></dt><dd>Linewrap for input line</dd>"
                               "<dt><b>Rafael \"EagleScreen\" Belmonte</b></dt><dd>Spanish translation</dd>"
                               "<dt><b>Sergiu Bivol</b></dt><dd>Romanian translation</dd>"
@@ -129,6 +130,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Johannes \"j0hu\" Huber</b></dt><dd>Many fixes and features, bug triaging</dd>"
                               "<dt><b>Theofilos Intzoglou</b></dt><dd>Greek translation</dd>"
                               "<dt><b>Jovan Jojkić</b></dt><dd>Serbian translation</dd>"
+                              "<dt><b>Allan Jude</b></dt><dd>Documentation improvements</dd>"
                               "<dt><b>Michael \"ycros\" Kedzierski</b></dt><dd>Mac fixes</dd>"
                               "<dt><b>Scott \"ScottK\" Kitterman<b></dt><dd>Kubuntu nightly packager, (packaging/build system) bughunter</dd>"
                               "<dt><b>Paul \"Haudrauf\" Klumpp</b></dt><dd>Initial design and mainwindow layout</dd>"
@@ -144,6 +146,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Michael \"mamarley\" Marley</b></dt><dd>Various fixes and improvements</dd>"
                               "<dt><b>Martin \"m4yer\" Mayer</b></dt><dd>German translation</dd>"
                               "<dt><b>Daniel \"hydrogen\" Meltzer</b></dt><dd>Various fixes and improvements</dd>"
+                              "<dt><b>Sebastian Meyer</b></dt><dd>Fixes</dd>"
                               "<dt><b>Daniel E. Moctezuma</b></dt><dd>Japanese translation</dd>"
                               "<dt><b>Chris \"kode54\" Moeller</b></dt><dd>Various fixes and improvements</dd>"
                               "<dt><b>Thomas Müller</b></dt><dd>Fixes, Debian packaging</dd>"
@@ -167,6 +170,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Dirk \"MarcLandis\" Rettschlag</b></dt><dd>Various fixes and new features</dd>"
                               "<dt><b>Miguel Revilla</b></dt><dd>Spanish translation</dd>"
                               "<dt><b>Jaak Ristioja</b></dt><dd>Fixes</dd>"
+                              "<dt><b>David \"Bombe\" Roden</b></dt><dd>Fixes</dd>"
                               "<dt><b>Henning \"honk\" Rohlfs</b></dt><dd>Various fixes</dd>"
                               "<dt><b>Stella \"differentreality\" Rouzi</b></dt><dd>Greek translation</dd>"
                               "<dt><b>\"salnx\"</b></dt><dd>Highlight configuration improvements</dd>"
@@ -177,6 +181,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>Tim \"xAFFE\" Schumacher</b></dt><dd>Fixes and feedback</dd>"
                               "<dt><b>\"sfionov\"</b></dt><dd>Russian translation</dd>"
                               "<dt><b>Harald \"apachelogger\" Sitter</b></dt><dd>{ku|U}buntu packager, motivator, promoter</dd>"
+                              "<dt><b>Ramanathan Sivagurunathan</b></dt><dd>Fixes</dd>"
                               "<dt><b>Stefanos Sofroniou</b></dt><dd>Greek translation</dd>"
                               "<dt><b>Rüdiger \"ruediger\" Sonderfeld</b></dt><dd>Emacs keybindings</dd>"
                               "<dt><b>Alexander Stein</b></dt><dd>Tray icon fix</dd>"
@@ -186,6 +191,7 @@ QString AboutDlg::contributors() const
                               "<dt><b>\"ToBeFree\"</b></dt><dd>German translation</dd>"
                               "<dt><b>Edward \"Aides\" Toroshchin</b></dt><dd>Russian translation</dd>"
                               "<dt><b>Adam \"adamt\" Tulinius</b></dt><dd>Early beta tester and bughunter, Danish translation</dd>"
+                              "<dt><b>Deniz Türkoglu</b></dt><dd>Mac fixes</dd>"
                               "<dt><b>Frederik M.J. \"freqmod\" Vestre</b></dt><dd>Norwegian translation</dd>"
                               "<dt><b>Atte Virtanen</b></dt><dd>Finnish translation</dd>"
                               "<dt><b>Pavel \"int\" Volkovitskiy</b></dt><dd>Early beta tester and bughunter</dd>"
