@@ -1022,13 +1022,15 @@ void MainWin::setupToolBars()
 #endif
 }
 
-#ifdef Q_WS_MAC
 void MainWin::saveMainToolBarStatus(bool enabled)
 {
+#ifdef Q_OS_MAC
     QtUiSettings uiSettings;
     uiSettings.setValue("ShowMainToolBar", enabled);
-}
+#else
+    Q_UNUSED(enabled);
 #endif
+}
 
 
 void MainWin::connectedToCore()
@@ -1595,9 +1597,7 @@ void MainWin::on_jumpHotBuffer_triggered()
     if (!_bufferHotList->rowCount())
         return;
 
-    QModelIndex topIndex = _bufferHotList->index(0, 0);
-    BufferId bufferId = _bufferHotList->data(topIndex, NetworkModel::BufferIdRole).value<BufferId>();
-    Client::bufferModel()->switchToBuffer(bufferId);
+    Client::bufferModel()->switchToBuffer(_bufferHotList->hottestBuffer());
 }
 
 
@@ -1648,6 +1648,9 @@ void MainWin::on_actionDebugNetworkModel_triggered()
 
 void MainWin::on_actionDebugHotList_triggered()
 {
+    _bufferHotList->invalidate();
+    _bufferHotList->sort(0, Qt::DescendingOrder);
+
     QTreeView *view = new QTreeView;
     view->setAttribute(Qt::WA_DeleteOnClose);
     view->setModel(_bufferHotList);
