@@ -22,6 +22,7 @@
 #define BUFFERHOTLISTFILTER_H
 
 #include <QSortFilterProxyModel>
+#include "types.h"
 
 class BufferHotListFilter : public QSortFilterProxyModel
 {
@@ -31,6 +32,7 @@ public:
     BufferHotListFilter(QAbstractItemModel *source, QObject *parent = 0);
 
     virtual inline int columnCount(const QModelIndex &) const { return 1; }
+    BufferId hottestBuffer();
 //   QVariant data(const QModelIndex &index, int role) const;
 
 protected:
