@@ -45,18 +45,19 @@ TabCompleter::TabCompleter(MultiLineEdit *_lineEdit)
     _enabled(false),
     _nickSuffix(": ")
 {
-    // use both an Action and generic eventFilter, to make the shortcut configurable
-    // yet still be able to reset() when required
+    // This Action just serves as a container for the custom shortcut and isn't actually handled;
+    // apparently, using tab as an Action shortcut  in an input widget is unreliable on some platforms (e.g. OS/2)
     _lineEdit->installEventFilter(this);
     ActionCollection *coll = GraphicalUi::actionCollection("General");
-    coll->addAction("TabCompletionKey", new Action(tr("Tab completion"), coll,
+    QAction *a = coll->addAction("TabCompletionKey", new Action(tr("Tab completion"), coll,
             this, SLOT(onTabCompletionKey()), QKeySequence(Qt::Key_Tab)));
+    a->setEnabled(false); // avoid catching the shortcut
 }
 
 
 void TabCompleter::onTabCompletionKey()
 {
-    complete();
+    // do nothing; we use the event filter instead
 }
 
 
@@ -179,9 +180,11 @@ bool TabCompleter::eventFilter(QObject *obj, QEvent *event)
 
     QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
 
-    if (keyEvent->key() != GraphicalUi::actionCollection("General")->action("TabCompletionKey")->shortcut()) {
+    if (keyEvent->key() == GraphicalUi::actionCollection("General")->action("TabCompletionKey")->shortcut()[0])
+        complete();
+    else
         reset();
-    }
+
     return false;
 }
 
